pub struct GraphExec { /* private fields */ }Expand description
Executable (instantiated) graph
Implementations
Sourceimpl GraphExec
impl GraphExec
Sourcepub fn launch(&mut self) -> Result<GraphExecResult>
pub fn launch(&mut self) -> Result<GraphExecResult>
Execute the graph
In the CPU emulation backend, nodes are executed sequentially in topological order. With a real GPU backend, independent nodes could be dispatched in parallel.
Sourcepub fn execution_count(&self) -> u64
pub fn execution_count(&self) -> u64
Get execution count
Sourcepub fn avg_execution_time_us(&self) -> u64
pub fn avg_execution_time_us(&self) -> u64
Get average execution time in microseconds
Sourcepub fn node_count(&self) -> usize
pub fn node_count(&self) -> usize
Get number of nodes