pub fn clear_kernel_context()Expand description
Clear the kernel context for the current thread.
After clearing, the accessor functions return their default values.
pub fn clear_kernel_context()Clear the kernel context for the current thread.
After clearing, the accessor functions return their default values.