MemoryMapper

Struct MemoryMapper 

pub struct MemoryMapper;
Maps CUDA memory spaces to Rust and WGSL equivalents.

Implementations

Source

impl MemoryMapper

pub fn to_rust(storage: &StorageClass) -> MemoryMapping

Map a CUDA StorageClass to its Rust representation.

pub fn rust_var_prefix(storage: &StorageClass, mutable: bool) -> String

Generate a Rust variable declaration prefix for the given storage class.

Examples
  • StorageClass::Shared -> "/* __shared__ */ let mut "
  • StorageClass::Constant -> "const "
  • StorageClass::Auto -> "let "
pub fn to_wgsl(storage: &StorageClass) -> MemoryMapping

Map a CUDA StorageClass to its WGSL representation.

pub fn wgsl_var_decl( storage: &StorageClass, name: &str, wgsl_type: &str, ) -> String

Generate a WGSL variable declaration for the given storage class.

Arguments
  • storage - The CUDA storage class
  • name - Variable name
  • wgsl_type - WGSL type string (e.g. “f32”, “array<f32, 256>”)
Returns

A complete WGSL variable declaration string.

pub fn wgsl_binding_decl( storage: &StorageClass, group: u32, binding: u32, name: &str, wgsl_type: &str, read_only: bool, ) -> String

Generate a WGSL binding declaration for a kernel parameter.

Arguments
  • storage - The CUDA storage class
  • group - Binding group number
  • binding - Binding index
  • name - Variable name
  • wgsl_type - WGSL type string
  • read_only - Whether the binding is read-only
pub fn parse_cuda_qualifier(qualifier: &str) -> StorageClass

Parse a CUDA memory space qualifier string into a StorageClass.

pub fn requires_barrier(storage: &StorageClass) -> bool

Returns true if the storage class requires barrier synchronisation before other threads can see writes.

pub fn is_read_only(storage: &StorageClass) -> bool

Returns true if the storage class is read-only.

pub fn wgsl_barrier(storage: &StorageClass) -> Option<&'static str>

Returns the WGSL barrier function name needed after writes to this memory space, if any.

pub fn rust_barrier(storage: &StorageClass) -> Option<&'static str>

Returns the Rust synchronization primitive needed after writes to this memory space, if any.